@@ -10,14 +10,13 @@ class PhysicalVolumeFilter(NetBoxModelFilterSet):
 
     class Meta:
         model = PhysicalVolume
-        fields = ["partition", "pv_name"]
+        fields = ["pv_name"]
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
         if not value.strip():
             return queryset
         qs_filter = (
-            Q(partition__icontains=value)
-            | Q(pv_name__icontains=value)
+            Q(pv_name__icontains=value)
         )
         return queryset.filter(qs_filter)
