@@ -109,25 +109,33 @@ class LVMSimpleForm(NetBoxModelForm):
         ]
 
     def save(self, *args, **kwargs):
-        instance = super().save(*args, **kwargs)
+        drive = super().save(*args, **kwargs)
         logger = logging.getLogger('netbox.plugins.netbox_storage')
 
-        logger.warning(f'--------- Instance: {instance}')
-        logger.warning(f'--------- Instance: {instance.pk}')
-        partition = Partition(drive=instance, device=instance.device_name, size=instance.size, type="Linux LVM")
-        partition.save()
-        logger.warning(f'{partition}')
-        vg = VolumeGroup(vg_name=self.vg_name)
-        vg.save()
-        logger.warning(f'{vg}')
-        physicalvolume = PhysicalVolume(partition=partition, pv_name=instance.device_name, vg=vg)
-        physicalvolume.save()
+        logger.warning(f'{self.instance}')
+        logger.warning(f'{self.instance.lv_name}')
+        logger.warning(f'{self.instance.vg_name}')
+        logger.warning(f'{self.instance.path}')
+        logger.warning(f'{self.instance.fs}')
+        logger.warning(f'{self.instance.size}')
+        logger.warning(f'{self.instance.virtual_machine}')
+
+        # logger.warning(f'--------- Instance: {instance}')
+        # logger.warning(f'--------- Instance: {instance.pk}')
+        # partition = Partition(drive=instance, device=instance.device_name, size=instance.size, type="Linux LVM")
+        # partition.save()
+        # logger.warning(f'{partition}')
+        # vg = VolumeGroup(vg_name=self.vg_name)
+        # vg.save()
+        # logger.warning(f'{vg}')
+        # physicalvolume = PhysicalVolume(partition=partition, pv_name=instance.device_name, vg=vg)
+        """physicalvolume.save()
         logger.warning(f'{physicalvolume}')
         logicalvolume = LogicalVolume(vg=vg, size=self.size, path=self.path, fs=self.fs)
         logger.warning(f'{logicalvolume}')
-        logicalvolume.save()
+        logicalvolume.save()"""
 
-        return instance
+        return drive
 
 
 class LVSimpleForm(NetBoxModelForm):
@@ -150,6 +158,10 @@ class LVSimpleForm(NetBoxModelForm):
         label="Path",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
     )
+    hard_drive_label = CharField(
+        label="Hard Drive Label",
+        help_text="The label of the hard drive e.g. D",
+    )
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
         label="Filesystem Name",
@@ -188,3 +200,16 @@ class LVSimpleForm(NetBoxModelForm):
             "virtual_machine",
             "description",
         )
+
+    def save(self, *args, **kwargs):
+        drive = super().save(*args, **kwargs)
+
+        # Assign/clear this IPAddress as the primary for the associated Device/VirtualMachine.
+        if self.instance.vg_name is not None:
+            print(f"{self.instance.vg_name}")
+        elif self.instance.lv_name is not None:
+            print(f"{self.instance.size}")
+        else:
+            print(f"{self.instance.hard_drive_label}")
+
+        return drive
